@@ -16,12 +16,15 @@
 #' @seealso  \code{\link[fda]{create.bspline.basis}} from package \code{\link[fda]{fda}}, for the most commonly used basis object type.
 #' @examples
 #'
+#' \dontrun{
 #'
 #' require(fda)
 #' bbasis6 <- create.bspline.basis(nbasis=6)
 #' inprod.cent(bbasis6)
 #' fbasis7 <- create.fourier.basis(nbasis=7)
 #' inprod.cent(fbasis7)
+
+#'}
 #'
 #' @export inprod.cent
 inprod.cent <- function(basis1, basis2=basis1, rng=NULL) {
@@ -29,8 +32,6 @@ inprod.cent <- function(basis1, basis2=basis1, rng=NULL) {
     if (samebasis & basis1$type=="fourier" & is.null(rng)) {
         res <- diag(basis1$nbasis)
         res[1,1] <- 0
-        rownames(res) <- colnames(res) <- basis1$names
-        return(res)
     }
     else {
         if (is.null(rng)) rng <- c(max(basis1$rangeval[1],basis2$rangeval[1]), min(basis1$rangeval[2],basis2$rangeval[2]))
@@ -44,13 +45,15 @@ inprod.cent <- function(basis1, basis2=basis1, rng=NULL) {
         allpts <- sort(allpts0)
         mult <- rep(diff(pts), each=7) * rep(c(41/140, 54/35, 27/140, 68/35, 27/140, 54/35, 41/140),(npts-1)) / 6
         dmult <- diag(mult)
-        evalmat1 <- eval.basis(allpts, basis1)
+        evalmat1 <- fda::eval.basis(allpts, basis1)
         int1 <- colSums(dmult %*% evalmat1)
-        evalmat2 <- eval.basis(allpts, basis2)
+        evalmat2 <- fda::eval.basis(allpts, basis2)
         int2 <- colSums(dmult %*% evalmat2)
         inprod <- t(evalmat1) %*% dmult %*% evalmat2
         res <- inprod - outer(int1, int2)/diff(rng)
         if (samebasis) res <- (res + t(res)) / 2
-        return(res)
     }
+    rownames(res) <- basis1$names
+    colnames(res) <- basis2$names
+    return(res)
 }
